@@ -18,12 +18,14 @@
 
 from __future__ import print_function
 
+import collections
 import getpass
 import inspect
 import os
 import sys
 import textwrap
 
+import decorator
 from oslo_utils import encodeutils
 from oslo_utils import strutils
 import prettytable
@@ -89,6 +91,15 @@ def arg(*args, **kwargs):
     return _decorator
 
 
+def exclusive_arg(group_name, *args, **kwargs):
+    """Decorator for CLI mutually exclusive args."""
+    def _decorator(func):
+        required = kwargs.pop('required', None)
+        add_exclusive_arg(func, group_name, required, *args, **kwargs)
+        return func
+    return _decorator
+
+
 def env(*args, **kwargs):
     """Returns the first environment variable set.
 
@@ -115,6 +126,24 @@ def add_arg(func, *args, **kwargs):
         func.arguments.insert(0, (args, kwargs))
 
 
+def add_exclusive_arg(func, group_name, required, *args, **kwargs):
+    """Bind CLI mutally exclusive arguments to a shell.py `do_foo` function."""
+
+    if not hasattr(func, 'exclusive_args'):
+        func.exclusive_args = collections.defaultdict(list)
+        # Default required to False
+        func.exclusive_args['__required__'] = collections.defaultdict(bool)
+
+    # NOTE(sirp): avoid dups that can occur when the module is shared across
+    # tests.
+    if (args, kwargs) not in func.exclusive_args[group_name]:
+        # Because of the semantics of decorator composition if we just append
+        # to the options list positional options will appear to be backwards.
+        func.exclusive_args[group_name].insert(0, (args, kwargs))
+        if required is not None:
+            func.exclusive_args['__required__'][group_name] = required
+
+
 def unauthenticated(func):
     """Adds 'unauthenticated' attribute to decorated function.
 
@@ -201,18 +230,21 @@ def keys_and_vals_to_strs(dictionary):
     return dict((to_str(k), to_str(v)) for k, v in dictionary.items())
 
 
-def print_dict(dct, dict_property="Property", wrap=0):
+def print_dict(dct, dict_property="Property", wrap=0, value_fields=None):
     """Print a `dict` as a table of two columns.
 
     :param dct: `dict` to print
     :param dict_property: name of the first column
     :param wrap: wrapping for the second column
+    :param value_fields: attributes that correspond to columns, in order
     """
     pt = prettytable.PrettyTable([dict_property, 'Value'])
+    if value_fields:
+        pt = prettytable.PrettyTable([dict_property] + list(value_fields))
     pt.align = 'l'
     for k, v in dct.items():
         # convert dict to str to check length
-        if isinstance(v, dict):
+        if isinstance(v, dict) and not value_fields:
             v = six.text_type(keys_and_vals_to_strs(v))
         if wrap > 0:
             v = textwrap.fill(six.text_type(v), wrap)
@@ -226,6 +258,9 @@ def print_dict(dct, dict_property="Property", wrap=0):
             for line in lines:
                 pt.add_row([col1, line])
                 col1 = ''
+        elif isinstance(v, dict):
+            vals = [v[field] for field in v if field in value_fields]
+            pt.add_row([k] + vals)
         elif isinstance(v, list):
             val = str([str(i) for i in v])
             pt.add_row([k, val])
@@ -289,3 +324,11 @@ def exit(msg=''):
     if msg:
         print(msg, file=sys.stderr)
     sys.exit(1)
+
+
+def deprecated(message):
+    @decorator.decorator
+    def wrapper(func, *args, **kwargs):
+        print(message)
+        return func(*args, **kwargs)
+    return wrapper
