@@ -18,6 +18,7 @@ import base64
 import binascii
 import os
 import re
+import shlex
 
 from oslo_serialization import jsonutils
 from oslo_utils import netutils
@@ -211,6 +212,10 @@ def parse_command(command):
     return " ".join(output)
 
 
+def parse_entrypoint(entrypoint):
+    return shlex.split(entrypoint)
+
+
 def parse_mounts(mounts):
     err_msg = ("Invalid mounts argument '%s'. mounts arguments must be of "
                "the form --mount source=<volume>,destination=<path>, "
@@ -324,8 +329,8 @@ def parse_health(hc_str):
 
 
 def _convert_healthcheck_para(time, err_msg):
-    int_pattern = '^\d+$'
-    time_pattern = '^\d+(s|m|h)$'
+    int_pattern = r'^\d+$'
+    time_pattern = r'^\d+(s|m|h)$'
     ret = 0
     if re.match(int_pattern, time):
         ret = int(time)
@@ -359,8 +364,9 @@ def base_url_for_url(url):
 
 
 def list_capsules(capsules):
-    columns = ('uuid', 'status', 'meta_name',
-               'meta_labels', 'containers_uuids', 'created_at', 'addresses')
+    for c in capsules:
+        format_container_addresses(c)
+    columns = ('uuid', 'name', 'status', 'addresses')
     utils.print_list(capsules, columns,
                      {'versions': print_list_field('versions')},
                      sortby_index=None)
