@@ -10,7 +10,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
 
 from zunclient.common.apiclient import exceptions as apiexec
 from zunclient.common import utils as zun_utils
@@ -28,6 +28,7 @@ def _get_container_args(**kwargs):
         'mounts': [],
         'nets': [],
         'command': [],
+        'entrypoint': [],
     }
     default_args.update(kwargs)
     return default_args
