@@ -184,6 +184,14 @@ def _show_container(container):
 @utils.arg('--registry',
            metavar='<registry>',
            help='The container image registry ID or name')
+@utils.arg('--host',
+           metavar='<host>',
+           help='Requested host to create containers. Admin only by default.'
+                '(Supported by API versions 1.39 or above)')
+@utils.arg('--entrypoint',
+           metavar='<entrypoint>',
+           help='The entrypoint which overwrites the default ENTRYPOINT '
+                'of the image. (Supported by API versions 1.40 or above)')
 def do_create(cs, args):
     """Create a container."""
     opts = {}
@@ -206,6 +214,8 @@ def do_create(cs, args):
     opts['availability_zone'] = args.availability_zone
     opts['command'] = args.command
     opts['registry'] = args.registry
+    opts['host'] = args.host
+    opts['entrypoint'] = zun_utils.parse_entrypoint(args.entrypoint)
     if args.healthcheck:
         opts['healthcheck'] = zun_utils.parse_health(args.healthcheck)
 
@@ -708,6 +718,14 @@ def do_kill(cs, args):
 @utils.arg('--registry',
            metavar='<registry>',
            help='The container image registry ID or name')
+@utils.arg('--host',
+           metavar='<host>',
+           help='Requested host to run containers. Admin only by default.'
+                '(Supported by API versions 1.39 or above)')
+@utils.arg('--entrypoint',
+           metavar='<entrypoint>',
+           help='The entrypoint which overwrites the default ENTRYPOINT '
+                'of the image. (Supported by API versions 1.40 or above)')
 def do_run(cs, args):
     """Run a command in a new container."""
     opts = {}
@@ -730,6 +748,8 @@ def do_run(cs, args):
     opts['availability_zone'] = args.availability_zone
     opts['command'] = args.command
     opts['registry'] = args.registry
+    opts['host'] = args.host
+    opts['entrypoint'] = zun_utils.parse_entrypoint(args.entrypoint)
     if args.healthcheck:
         opts['healthcheck'] = zun_utils.parse_health(args.healthcheck)
 
